aboutsummaryrefslogtreecommitdiffstats
path: root/themes/default/js/ui/jquery.ui.mouse.js
diff options
context:
space:
mode:
authorrvelices <rv-github@modusoptimus.com>2013-02-18 21:18:40 +0000
committerrvelices <rv-github@modusoptimus.com>2013-02-18 21:18:40 +0000
commit74373ea7175bcf6be2732e6d59f037f79f88ca96 (patch)
treee8799eea7707f9aae6ba3ccb2aa7ce315f0be383 /themes/default/js/ui/jquery.ui.mouse.js
parentf2da009c0f744c9197c652c5012323e69dd96308 (diff)
upgraded jquery ui from 1.9.0 to 1.10.1
git-svn-id: http://piwigo.org/svn/trunk@20824 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'themes/default/js/ui/jquery.ui.mouse.js')
-rw-r--r--themes/default/js/ui/jquery.ui.mouse.js52
1 files changed, 26 insertions, 26 deletions
diff --git a/themes/default/js/ui/jquery.ui.mouse.js b/themes/default/js/ui/jquery.ui.mouse.js
index e1b9d5fa3..046c2eb18 100644
--- a/themes/default/js/ui/jquery.ui.mouse.js
+++ b/themes/default/js/ui/jquery.ui.mouse.js
@@ -1,8 +1,8 @@
/*!
* jQuery UI Mouse 1.9.0
* http://jqueryui.com
*
- * Copyright 2012 jQuery Foundation and other contributors
+ * Copyright 2013 jQuery Foundation and other contributors
* Released under the MIT license.
* http://jquery.org/license
*
@@ -14,14 +14,14 @@
(function( $, undefined ) {
var mouseHandled = false;
-$( document ).mouseup( function( e ) {
+$( document ).mouseup( function() {
mouseHandled = false;
});
$.widget("ui.mouse", {
- version: "1.9.0",
+ version: "1.10.1",
options: {
- cancel: 'input,textarea,button,select,option',
+ cancel: "input,textarea,button,select,option",
distance: 1,
delay: 0
},
@@ -29,12 +29,12 @@ $.widget("ui.mouse", {
var that = this;
this.element
- .bind('mousedown.'+this.widgetName, function(event) {
+ .bind("mousedown."+this.widgetName, function(event) {
return that._mouseDown(event);
})
- .bind('click.'+this.widgetName, function(event) {
- if (true === $.data(event.target, that.widgetName + '.preventClickEvent')) {
- $.removeData(event.target, that.widgetName + '.preventClickEvent');
+ .bind("click."+this.widgetName, function(event) {
+ if (true === $.data(event.target, that.widgetName + ".preventClickEvent")) {
+ $.removeData(event.target, that.widgetName + ".preventClickEvent");
event.stopImmediatePropagation();
return false;
}
@@ -46,11 +46,11 @@ $.widget("ui.mouse", {
// TODO: make sure destroying one instance of mouse doesn't mess with
// other instances of mouse
_mouseDestroy: function() {
- this.element.unbind('.'+this.widgetName);
+ this.element.unbind("."+this.widgetName);
if ( this._mouseMoveDelegate ) {
$(document)
- .unbind('mousemove.'+this.widgetName, this._mouseMoveDelegate)
- .unbind('mouseup.'+this.widgetName, this._mouseUpDelegate);
+ .unbind("mousemove."+this.widgetName, this._mouseMoveDelegate)
+ .unbind("mouseup."+this.widgetName, this._mouseUpDelegate);
}
},
@@ -88,8 +88,8 @@ $.widget("ui.mouse", {
}
// Click event may never have fired (Gecko & Opera)
- if (true === $.data(event.target, this.widgetName + '.preventClickEvent')) {
- $.removeData(event.target, this.widgetName + '.preventClickEvent');
+ if (true === $.data(event.target, this.widgetName + ".preventClickEvent")) {
+ $.removeData(event.target, this.widgetName + ".preventClickEvent");
}
// these delegates are required to keep context
@@ -100,18 +100,18 @@ $.widget("ui.mouse", {
return that._mouseUp(event);
};
$(document)
- .bind('mousemove.'+this.widgetName, this._mouseMoveDelegate)
- .bind('mouseup.'+this.widgetName, this._mouseUpDelegate);
+ .bind("mousemove."+this.widgetName, this._mouseMoveDelegate)
+ .bind("mouseup."+this.widgetName, this._mouseUpDelegate);
event.preventDefault();
-
+
mouseHandled = true;
return true;
},
_mouseMove: function(event) {
// IE mouseup check - mouseup happened when mouse was out of window
- if ($.browser.msie && !(document.documentMode >= 9) && !event.button) {
+ if ($.ui.ie && ( !document.documentMode || document.documentMode < 9 ) && !event.button) {
return this._mouseUp(event);
}
@@ -131,14 +131,14 @@ $.widget("ui.mouse", {
_mouseUp: function(event) {
$(document)
- .unbind('mousemove.'+this.widgetName, this._mouseMoveDelegate)
- .unbind('mouseup.'+this.widgetName, this._mouseUpDelegate);
+ .unbind("mousemove."+this.widgetName, this._mouseMoveDelegate)
+ .unbind("mouseup."+this.widgetName, this._mouseUpDelegate);
if (this._mouseStarted) {
this._mouseStarted = false;
if (event.target === this._mouseDownEvent.target) {
- $.data(event.target, this.widgetName + '.preventClickEvent', true);
+ $.data(event.target, this.widgetName + ".preventClickEvent", true);
}
this._mouseStop(event);
@@ -155,15 +155,15 @@ $.widget("ui.mouse", {
);
},
- _mouseDelayMet: function(event) {
+ _mouseDelayMet: function(/* event */) {
return this.mouseDelayMet;
},
// These are placeholder methods, to be overriden by extending plugin
- _mouseStart: function(event) {},
- _mouseDrag: function(event) {},
- _mouseStop: function(event) {},
- _mouseCapture: function(event) { return true; }
+ _mouseStart: function(/* event */) {},
+ _mouseDrag: function(/* event */) {},
+ _mouseStop: function(/* event */) {},
+ _mouseCapture: function(/* event */) { return true; }
});
})(jQuery);
@@ -1,8 +1,8 @@
/*!
- * jQuery UI Mouse 1.9.0
+ * jQuery UI Mouse 1.10.1
* http://jqueryui.com
*